==> myfaces-tobago-5.15.1-dist.zip: org/apache/myfaces/tobago/context/TobagoExceptionHandlerFactory.java <==
/*
 * Licensed to the Apache Software Foundation (ASF) under one
 * or more contributor license agreements.  See the NOTICE file
 * distributed with this work for additional information
 * regarding copyright ownership.  The ASF licenses this file
 * to you under the Apache License, Version 2.0 (the
 * "License"); you may not use this file except in compliance
 * with the License.  You may obtain a copy of the License at
 *
 *   http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing,
 * software distributed under the License is distributed on an
 * "AS IS" BASIS, WITHOUT WARRANTIES OR CONDITIONS OF ANY
 * KIND, either express or implied.  See the License for the
 * specific language governing permissions and limitations
 * under the License.
 */

package org.apache.myfaces.tobago.context;

import org.apache.myfaces.tobago.config.TobagoConfig;

import javax.faces.context.ExceptionHandler;
import javax.faces.context.ExceptionHandlerFactory;
import javax.faces.context.FacesContext;

/**
 * The TobagoExceptionHandler is activated by default via the basic faces-config.xml of tobago-core.
 * To disable, set the enableTobagoExceptionHandler to false in the tobago-config.xml of the application.
 */
public class TobagoExceptionHandlerFactory extends ExceptionHandlerFactory {

  public TobagoExceptionHandlerFactory(final ExceptionHandlerFactory parent) {
    super(parent);
  }

  @Override
  public ExceptionHandler getExceptionHandler() {
    if (TobagoConfig.getInstance(FacesContext.getCurrentInstance()).isEnableTobagoExceptionHandler()) {
      return new TobagoExceptionHandler(getWrapped().getExceptionHandler());
    } else {
      return getWrapped().getExceptionHandler();
    }
  }
}

==> myfaces-tobago-6.7.0-dist.zip: org/apache/myfaces/tobago/context/TobagoExceptionHandlerFactory.java <==
/*
 * Licensed to the Apache Software Foundation (ASF) under one
 * or more contributor license agreements.  See the NOTICE file
 * distributed with this work for additional information
 * regarding copyright ownership.  The ASF licenses this file
 * to you under the Apache License, Version 2.0 (the
 * "License"); you may not use this file except in compliance
 * with the License.  You may obtain a copy of the License at
 *
 *   http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing,
 * software distributed under the License is distributed on an
 * "AS IS" BASIS, WITHOUT WARRANTIES OR CONDITIONS OF ANY
 * KIND, either express or implied.  See the License for the
 * specific language governing permissions and limitations
 * under the License.
 */

package org.apache.myfaces.tobago.context;

import org.apache.myfaces.tobago.config.TobagoConfig;

import jakarta.faces.context.ExceptionHandler;
import jakarta.faces.context.ExceptionHandlerFactory;
import jakarta.faces.context.FacesContext;

/**
 * The TobagoExceptionHandler is activated by default via the basic faces-config.xml of tobago-core.
 * To disable, set the enableTobagoExceptionHandler to false in the tobago-config.xml of the application.
 */
public class TobagoExceptionHandlerFactory extends ExceptionHandlerFactory {

  public TobagoExceptionHandlerFactory(final ExceptionHandlerFactory parent) {
    super(parent);
  }

  @Override
  public ExceptionHandler getExceptionHandler() {
    if (TobagoConfig.getInstance(FacesContext.getCurrentInstance()).isEnableTobagoExceptionHandler()) {
      return new TobagoExceptionHandler(getWrapped().getExceptionHandler());
    } else {
      return getWrapped().getExceptionHandler();
    }
  }
}
